clear
close all
clc

%% Read the model, assign parameters, solve, find the steady state
m = Model.fromFile('openEconomy.model','linear',true);

m.c1_l_y_gap  = 0.1;
m.c2_l_y_gap  = 0.65;
m.c3_l_y_gap  = 0.10;
m.c4_l_y_gap  = 0.10;
m.c5_l_y_gap  = 0.10;

m.c1_dl_cpi   = 0.50;
m.c2_dl_cpi   = 0.30;
m.c3_dl_cpi   = 0.20;
m.c4_dl_cpi   = 0.05;

m.c1_i        = 0.8;
m.c2_i        = 1.75;
m.c3_i        = 0.3;

m.c_e_l_s     = 0.85;

m.dl_cpi_tar  = 7.5;
m.ss_dl_y_tnd = 5.5;
m.c0_dl_y_tnd = 0.9;
m.c1_dl_y_tnd = 0.1;

m.ss_prem     = 3;
m.ss_dl_z_tnd =-5;

% m = alter(m,2);
% m.param = [0.1 0.2];

m = solve(m);
m = sstate(m);

%% Run impulse responses, report

list_to_plot = {'l_y_gap', 'dl_cpi', 'i','l_s','l_z_gap','r_gap','l_z','r','l_cpi'};

% demand shock - simulation in deviations from steady-state
d = zerodb(m, 0:20);
d.shock_l_y_gap(1) = 1;
s = simulate(m, d, 1:20, 'Deviation',true);
dbplot(s, 0:16, list_to_plot,'lineWidth',3);
set(gcf,'Name','Demand shock - deviation from steady-state / BGP');

% supply shock - simulation in deviations from steady-state
d2 = zerodb(m, 0:20);
d2.shock_dl_cpi(1) = 1;
s2 = simulate(m, d2, 1:20, 'Deviation',true);
dbplot(s2, 0:16, list_to_plot,'lineWidth',3);
set(gcf,'Name','Supply shock - deviation from steady-state / BGP');

% monetary policy shock - simulation in deviations from steady-state
d = zerodb(m, 0:20);
d.shock_i(1) = 1;
s = simulate(m, d, 1:20, 'Deviation',true);
dbplot(s, 0:16, list_to_plot,'lineWidth',3);
set(gcf,'Name','Monetary policy shock - deviation from steady-state / BGP');

% exchange rate shock - simulation in deviations from steady-state
d = zerodb(m, 0:20);
d.shock_l_s(1) = 1;
s = simulate(m, d, 1:20, 'Deviation',true);
dbplot(s, 0:16, list_to_plot,'lineWidth',3);
set(gcf,'Name','Exchange rate shock');
